# Generated by Django 2.1.4 on 2019-02-11 09:19

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CanIHitIt',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_type', models.CharField(db_index=True, max_length=32)),
                ('object_id', models.IntegerField(db_index=True)),
                ('session_key', models.CharField(db_index=True, max_length=40)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]
